NotPaid class

A widget that fades as deadline comes closer and hides completely when the deadline is reached.

Inheritance

Constructors

NotPaid({Key? key, DateTime? dueDate, TextDirection directionality = TextDirection.ltr, Duration duration = const Duration(seconds: 5), bool showBanner = true, int? deadline, required Widget child, bool enabled = true, String deadlineReachedMessage = "You've reached the deadline!", String deadlineMessageBuilder(DateTime)?})
Default constructor
const

Properties

child Widget
Child widget. MaterialApp in most cases
final
deadline int
Deadline in days after the due date for the payment. This will be used to calculate opacity.
final
deadlineMessageBuilder String Function(DateTime)?
Allows to construct custom message to display before deadline is reached. DateTime param is the deadline date.
final
deadlineReachedMessage String
Text to display when/after deadline is reached.
final
directionality TextDirection
Default is TextDirection.ltr
final
dueDate DateTime?
Due date for the payment. This will be used to calculate opacity.
final
duration Duration
Will show deadline info banner for this duration and then will hide it.
final
enabled bool
Allows to enable/disable the widget
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBanner bool
If set to true, will show a banner with deadline info on the bottom of the app for given duration.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<NotPaid>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited